@@ -20,7 +20,6 @@
 #define GRANTLEEPLAINTEXTEDITOR_H
 
 #include "kpimtextedit/plaintexteditor.h"
-#include "config-grantleethemeeditor.h"
 #include <KSyntaxHighlighting/Repository>
 
 namespace KPIMTextEdit {
@@ -40,7 +39,7 @@ protected:
     void keyPressEvent(QKeyEvent *e) override;
 
 protected:
-    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
+    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter = nullptr;
 private:
     void initCompleter();
     KSyntaxHighlighting::Repository mRepo;
